emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r112594: * lisp/isearch.el (isearch-c


From: Juri Linkov
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r112594: * lisp/isearch.el (isearch-char-by-name): Rename from
Date: Thu, 16 May 2013 02:21:01 +0300
User-agent: Bazaar (2.6b2)

------------------------------------------------------------
revno: 112594
fixes bug: http://debbugs.gnu.org/13348
committer: Juri Linkov <address@hidden>
branch nick: trunk
timestamp: Thu 2013-05-16 02:21:01 +0300
message:
  * lisp/isearch.el (isearch-char-by-name): Rename from
  `isearch-insert-char-by-name'.  Doc fix.
  (isearch-forward): Mention `isearch-char-by-name' in
  the docstring.
modified:
  lisp/ChangeLog
  lisp/isearch.el
=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog    2013-05-15 23:14:18 +0000
+++ b/lisp/ChangeLog    2013-05-15 23:21:01 +0000
@@ -1,5 +1,10 @@
 2013-05-15  Juri Linkov  <address@hidden>
 
+       * isearch.el (isearch-char-by-name): Rename from
+       `isearch-insert-char-by-name'.  Doc fix.
+       (isearch-forward): Mention `isearch-char-by-name' in
+       the docstring.  (Bug#13348)
+
        * isearch.el (minibuffer-local-isearch-map): Bind "\r" to
        `exit-minibuffer' instead of
        `isearch-nonincremental-exit-minibuffer'.

=== modified file 'lisp/isearch.el'
--- a/lisp/isearch.el   2013-05-15 23:14:18 +0000
+++ b/lisp/isearch.el   2013-05-15 23:21:01 +0000
@@ -515,12 +515,12 @@
     (define-key map "\M-so" 'isearch-occur)
     (define-key map "\M-shr" 'isearch-highlight-regexp)
 
     ;; The key translations defined in the C-x 8 prefix should insert
     ;; characters into the search string.  See iso-transl.el.
     (define-key map "\C-x" nil)
     (define-key map [?\C-x t] 'isearch-other-control-char)
     (define-key map "\C-x8" nil)
-    (define-key map "\C-x8\r" 'isearch-insert-char-by-name)
+    (define-key map "\C-x8\r" 'isearch-char-by-name)
 
     map)
   "Keymap for `isearch-mode'.")
@@ -679,6 +679,8 @@
 Type \\[isearch-yank-pop] to replace string just yanked into search prompt
  with string killed before it.
 Type \\[isearch-quote-char] to quote control character to search for it.
+Type \\[isearch-char-by-name] to add a character to search by Unicode name,\
+ with completion.
 \\[isearch-abort] while searching or when search has failed cancels input\
  back to what has
  been found successfully.
@@ -1870,11 +1872,12 @@
    (lambda () (let ((inhibit-field-text-motion t))
                (line-end-position (if (eolp) 2 1))))))
 
-(defun isearch-insert-char-by-name ()
-  "Read a character by its Unicode name and insert it into search string."
+(defun isearch-char-by-name ()
+  "Read a character by its Unicode name and add it to the search string.
+Completion is available like in `read-char-by-name' used by `insert-char'."
   (interactive)
   (with-isearch-suspended
-   (let ((char (read-char-by-name "Insert character (Unicode name or hex): ")))
+   (let ((char (read-char-by-name "Add character to search (Unicode name or 
hex): ")))
      (when char
        (setq isearch-new-string (concat isearch-string (string char))
@@ -515,12 +515,12 @@
     (define-key map "\M-shr" 'isearch-highlight-regexp)
 
-    ;; The key translations defined in the C-x 8 prefix should insert
-    ;; characters into the search string.  See iso-transl.el.
+    ;; The key translations defined in the C-x 8 prefix should add
+    ;; characters to the search string.  See iso-transl.el.
     (define-key map "\C-x" nil)
     (define-key map [?\C-x t] 'isearch-other-control-char)
             isearch-new-message (concat isearch-message


reply via email to

[Prev in Thread] Current Thread [Next in Thread]